# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.enumeration
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.foundation.numerics
import winsdk.windows.graphics.imaging
import winsdk.windows.media
import winsdk.windows.media.devices.core

class PerceptionFrameSourceAccessStatus(enum.IntEnum):
    UNSPECIFIED = 0
    ALLOWED = 1
    DENIED_BY_USER = 2
    DENIED_BY_SYSTEM = 3

class PerceptionFrameSourcePropertyChangeStatus(enum.IntEnum):
    UNKNOWN = 0
    ACCEPTED = 1
    LOST_CONTROL = 2
    PROPERTY_NOT_SUPPORTED = 3
    PROPERTY_READ_ONLY = 4
    VALUE_OUT_OF_RANGE = 5

Self = typing.TypeVar('Self')

class KnownCameraIntrinsicsProperties(winsdk.system.Object):
    focal_length: typing.ClassVar[str]
    principal_point: typing.ClassVar[str]
    radial_distortion: typing.ClassVar[str]
    tangential_distortion: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KnownCameraIntrinsicsProperties: ...

class KnownPerceptionColorFrameSourceProperties(winsdk.system.Object):
    auto_exposure_enabled: typing.ClassVar[str]
    exposure: typing.ClassVar[str]
    exposure_compensation: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KnownPerceptionColorFrameSourceProperties: ...

class KnownPerceptionDepthFrameSourceProperties(winsdk.system.Object):
    max_depth: typing.ClassVar[str]
    min_depth: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KnownPerceptionDepthFrameSourceProperties: ...

class KnownPerceptionFrameSourceProperties(winsdk.system.Object):
    device_model_version: typing.ClassVar[str]
    enclosure_location: typing.ClassVar[str]
    frame_kind: typing.ClassVar[str]
    id: typing.ClassVar[str]
    physical_device_ids: typing.ClassVar[str]
    device_id: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KnownPerceptionFrameSourceProperties: ...

class KnownPerceptionInfraredFrameSourceProperties(winsdk.system.Object):
    active_illumination_enabled: typing.ClassVar[str]
    ambient_subtraction_enabled: typing.ClassVar[str]
    auto_exposure_enabled: typing.ClassVar[str]
    exposure: typing.ClassVar[str]
    exposure_compensation: typing.ClassVar[str]
    interleaved_illumination_enabled: typing.ClassVar[str]
    structure_light_pattern_enabled: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KnownPerceptionInfraredFrameSourceProperties: ...

class KnownPerceptionVideoFrameSourceProperties(winsdk.system.Object):
    available_video_profiles: typing.ClassVar[str]
    camera_intrinsics: typing.ClassVar[str]
    is_mirrored: typing.ClassVar[str]
    supported_video_profiles: typing.ClassVar[str]
    video_profile: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KnownPerceptionVideoFrameSourceProperties: ...

class KnownPerceptionVideoProfileProperties(winsdk.system.Object):
    bitmap_alpha_mode: typing.ClassVar[str]
    bitmap_pixel_format: typing.ClassVar[str]
    frame_duration: typing.ClassVar[str]
    height: typing.ClassVar[str]
    width: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KnownPerceptionVideoProfileProperties: ...

class PerceptionColorFrame(winsdk.system.Object):
    video_frame: typing.Optional[winsdk.windows.media.VideoFrame]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionColorFrame: ...
    def close(self) -> None: ...

class PerceptionColorFrameArrivedEventArgs(winsdk.system.Object):
    relative_time: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionColorFrameArrivedEventArgs: ...
    def try_open_frame(self) -> typing.Optional[PerceptionColorFrame]: ...

class PerceptionColorFrameReader(winsdk.system.Object):
    is_paused: winsdk.system.Boolean
    source: typing.Optional[PerceptionColorFrameSource]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionColorFrameReader: ...
    def close(self) -> None: ...
    def try_read_latest_frame(self) -> typing.Optional[PerceptionColorFrame]: ...
    def add_frame_arrived(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionColorFrameReader, PerceptionColorFrameArrivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_arrived(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PerceptionColorFrameSource(winsdk.system.Object):
    active: winsdk.system.Boolean
    available: winsdk.system.Boolean
    available_video_profiles: typing.Optional[winsdk.windows.foundation.collections.IVectorView[PerceptionVideoProfile]]
    camera_intrinsics: typing.Optional[winsdk.windows.media.devices.core.CameraIntrinsics]
    device_kind: str
    display_name: str
    id: str
    is_controlled: winsdk.system.Boolean
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]]
    supported_video_profiles: typing.Optional[winsdk.windows.foundation.collections.IVectorView[PerceptionVideoProfile]]
    video_profile: typing.Optional[PerceptionVideoProfile]
    device_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionColorFrameSource: ...
    def acquire_control_session(self) -> typing.Optional[PerceptionControlSession]: ...
    def can_control_independently_from(self, target_id: str) -> winsdk.system.Boolean: ...
    @staticmethod
    def create_watcher() -> typing.Optional[PerceptionColorFrameSourceWatcher]: ...
    @staticmethod
    def find_all_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[PerceptionColorFrameSource]]: ...
    @staticmethod
    def from_id_async(id: str) -> winsdk.windows.foundation.IAsyncOperation[PerceptionColorFrameSource]: ...
    def is_correlated_with(self, target_id: str) -> winsdk.system.Boolean: ...
    def open_reader(self) -> typing.Optional[PerceptionColorFrameReader]: ...
    @staticmethod
    def request_access_async() -> winsdk.windows.foundation.IAsyncOperation[PerceptionFrameSourceAccessStatus]: ...
    def try_get_depth_correlated_camera_intrinsics_async(self, correlated_depth_frame_source: typing.Optional[PerceptionDepthFrameSource]) -> winsdk.windows.foundation.IAsyncOperation[PerceptionDepthCorrelatedCameraIntrinsics]: ...
    def try_get_depth_correlated_coordinate_mapper_async(self, target_source_id: str, correlated_depth_frame_source: typing.Optional[PerceptionDepthFrameSource]) -> winsdk.windows.foundation.IAsyncOperation[PerceptionDepthCorrelatedCoordinateMapper]: ...
    def try_get_transform_to(self, target_id: str) -> typing.Tuple[winsdk.system.Boolean, winsdk.windows.foundation.numerics.Matrix4x4]: ...
    def try_set_video_profile_async(self, control_session: typing.Optional[PerceptionControlSession], profile: typing.Optional[PerceptionVideoProfile]) -> winsdk.windows.foundation.IAsyncOperation[PerceptionFrameSourcePropertyChangeResult]: ...
    def add_active_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionColorFrameSource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_active_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_available_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionColorFrameSource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_available_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_camera_intrinsics_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionColorFrameSource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_camera_intrinsics_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_properties_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionColorFrameSource, PerceptionFrameSourcePropertiesChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_properties_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_video_profile_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionColorFrameSource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_video_profile_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PerceptionColorFrameSourceAddedEventArgs(winsdk.system.Object):
    frame_source: typing.Optional[PerceptionColorFrameSource]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionColorFrameSourceAddedEventArgs: ...

class PerceptionColorFrameSourceRemovedEventArgs(winsdk.system.Object):
    frame_source: typing.Optional[PerceptionColorFrameSource]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionColorFrameSourceRemovedEventArgs: ...

class PerceptionColorFrameSourceWatcher(winsdk.system.Object):
    status: winsdk.windows.devices.enumeration.DeviceWatcherStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionColorFrameSourceWatcher: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    def add_enumeration_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionColorFrameSourceWatcher, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_enumeration_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_source_added(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionColorFrameSourceWatcher, PerceptionColorFrameSourceAddedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_source_added(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_source_removed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionColorFrameSourceWatcher, PerceptionColorFrameSourceRemovedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_source_removed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_stopped(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionColorFrameSourceWatcher, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_stopped(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PerceptionControlSession(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionControlSession: ...
    def close(self) -> None: ...
    def try_set_property_async(self, name: str, value: typing.Optional[winsdk.system.Object]) -> winsdk.windows.foundation.IAsyncOperation[PerceptionFrameSourcePropertyChangeResult]: ...
    def add_control_lost(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionControlSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_control_lost(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PerceptionDepthCorrelatedCameraIntrinsics(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionDepthCorrelatedCameraIntrinsics: ...
    def unproject_all_pixels_at_correlated_depth_async(self, depth_frame: typing.Optional[PerceptionDepthFrame], results: winsdk.system.Array[winsdk.windows.foundation.numerics.Vector3]) -> winsdk.windows.foundation.IAsyncAction: ...
    def unproject_pixel_at_correlated_depth(self, pixel_coordinate: winsdk.windows.foundation.Point, depth_frame: typing.Optional[PerceptionDepthFrame]) -> winsdk.windows.foundation.numerics.Vector3: ...
    def unproject_pixels_at_correlated_depth(self, source_coordinates: winsdk.system.Array[winsdk.windows.foundation.Point], depth_frame: typing.Optional[PerceptionDepthFrame], results: winsdk.system.Array[winsdk.windows.foundation.numerics.Vector3]) -> None: ...
    def unproject_region_pixels_at_correlated_depth_async(self, region: winsdk.windows.foundation.Rect, depth_frame: typing.Optional[PerceptionDepthFrame], results: winsdk.system.Array[winsdk.windows.foundation.numerics.Vector3]) -> winsdk.windows.foundation.IAsyncAction: ...

class PerceptionDepthCorrelatedCoordinateMapper(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionDepthCorrelatedCoordinateMapper: ...
    def map_all_pixels_to_target_async(self, depth_frame: typing.Optional[PerceptionDepthFrame], target_coordinates: winsdk.system.Array[winsdk.windows.foundation.Point]) -> winsdk.windows.foundation.IAsyncAction: ...
    def map_pixel_to_target(self, source_pixel_coordinate: winsdk.windows.foundation.Point, depth_frame: typing.Optional[PerceptionDepthFrame]) -> winsdk.windows.foundation.Point: ...
    def map_pixels_to_target(self, source_coordinates: winsdk.system.Array[winsdk.windows.foundation.Point], depth_frame: typing.Optional[PerceptionDepthFrame], results: winsdk.system.Array[winsdk.windows.foundation.Point]) -> None: ...
    def map_region_of_pixels_to_target_async(self, region: winsdk.windows.foundation.Rect, depth_frame: typing.Optional[PerceptionDepthFrame], target_coordinates: winsdk.system.Array[winsdk.windows.foundation.Point]) -> winsdk.windows.foundation.IAsyncAction: ...

class PerceptionDepthFrame(winsdk.system.Object):
    video_frame: typing.Optional[winsdk.windows.media.VideoFrame]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionDepthFrame: ...
    def close(self) -> None: ...

class PerceptionDepthFrameArrivedEventArgs(winsdk.system.Object):
    relative_time: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionDepthFrameArrivedEventArgs: ...
    def try_open_frame(self) -> typing.Optional[PerceptionDepthFrame]: ...

class PerceptionDepthFrameReader(winsdk.system.Object):
    is_paused: winsdk.system.Boolean
    source: typing.Optional[PerceptionDepthFrameSource]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionDepthFrameReader: ...
    def close(self) -> None: ...
    def try_read_latest_frame(self) -> typing.Optional[PerceptionDepthFrame]: ...
    def add_frame_arrived(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionDepthFrameReader, PerceptionDepthFrameArrivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_arrived(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PerceptionDepthFrameSource(winsdk.system.Object):
    active: winsdk.system.Boolean
    available: winsdk.system.Boolean
    available_video_profiles: typing.Optional[winsdk.windows.foundation.collections.IVectorView[PerceptionVideoProfile]]
    camera_intrinsics: typing.Optional[winsdk.windows.media.devices.core.CameraIntrinsics]
    device_kind: str
    display_name: str
    id: str
    is_controlled: winsdk.system.Boolean
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]]
    supported_video_profiles: typing.Optional[winsdk.windows.foundation.collections.IVectorView[PerceptionVideoProfile]]
    video_profile: typing.Optional[PerceptionVideoProfile]
    device_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionDepthFrameSource: ...
    def acquire_control_session(self) -> typing.Optional[PerceptionControlSession]: ...
    def can_control_independently_from(self, target_id: str) -> winsdk.system.Boolean: ...
    @staticmethod
    def create_watcher() -> typing.Optional[PerceptionDepthFrameSourceWatcher]: ...
    @staticmethod
    def find_all_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[PerceptionDepthFrameSource]]: ...
    @staticmethod
    def from_id_async(id: str) -> winsdk.windows.foundation.IAsyncOperation[PerceptionDepthFrameSource]: ...
    def is_correlated_with(self, target_id: str) -> winsdk.system.Boolean: ...
    def open_reader(self) -> typing.Optional[PerceptionDepthFrameReader]: ...
    @staticmethod
    def request_access_async() -> winsdk.windows.foundation.IAsyncOperation[PerceptionFrameSourceAccessStatus]: ...
    def try_get_depth_correlated_camera_intrinsics_async(self, target: typing.Optional[PerceptionDepthFrameSource]) -> winsdk.windows.foundation.IAsyncOperation[PerceptionDepthCorrelatedCameraIntrinsics]: ...
    def try_get_depth_correlated_coordinate_mapper_async(self, target_id: str, depth_frame_source_to_map_with: typing.Optional[PerceptionDepthFrameSource]) -> winsdk.windows.foundation.IAsyncOperation[PerceptionDepthCorrelatedCoordinateMapper]: ...
    def try_get_transform_to(self, target_id: str) -> typing.Tuple[winsdk.system.Boolean, winsdk.windows.foundation.numerics.Matrix4x4]: ...
    def try_set_video_profile_async(self, control_session: typing.Optional[PerceptionControlSession], profile: typing.Optional[PerceptionVideoProfile]) -> winsdk.windows.foundation.IAsyncOperation[PerceptionFrameSourcePropertyChangeResult]: ...
    def add_active_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionDepthFrameSource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_active_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_available_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionDepthFrameSource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_available_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_camera_intrinsics_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionDepthFrameSource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_camera_intrinsics_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_properties_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionDepthFrameSource, PerceptionFrameSourcePropertiesChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_properties_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_video_profile_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionDepthFrameSource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_video_profile_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PerceptionDepthFrameSourceAddedEventArgs(winsdk.system.Object):
    frame_source: typing.Optional[PerceptionDepthFrameSource]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionDepthFrameSourceAddedEventArgs: ...

class PerceptionDepthFrameSourceRemovedEventArgs(winsdk.system.Object):
    frame_source: typing.Optional[PerceptionDepthFrameSource]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionDepthFrameSourceRemovedEventArgs: ...

class PerceptionDepthFrameSourceWatcher(winsdk.system.Object):
    status: winsdk.windows.devices.enumeration.DeviceWatcherStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionDepthFrameSourceWatcher: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    def add_enumeration_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionDepthFrameSourceWatcher, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_enumeration_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_source_added(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionDepthFrameSourceWatcher, PerceptionDepthFrameSourceAddedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_source_added(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_source_removed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionDepthFrameSourceWatcher, PerceptionDepthFrameSourceRemovedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_source_removed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_stopped(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionDepthFrameSourceWatcher, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_stopped(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PerceptionFrameSourcePropertiesChangedEventArgs(winsdk.system.Object):
    collection_change: winsdk.windows.foundation.collections.CollectionChange
    key: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionFrameSourcePropertiesChangedEventArgs: ...

class PerceptionFrameSourcePropertyChangeResult(winsdk.system.Object):
    new_value: typing.Optional[winsdk.system.Object]
    status: PerceptionFrameSourcePropertyChangeStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionFrameSourcePropertyChangeResult: ...

class PerceptionInfraredFrame(winsdk.system.Object):
    video_frame: typing.Optional[winsdk.windows.media.VideoFrame]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionInfraredFrame: ...
    def close(self) -> None: ...

class PerceptionInfraredFrameArrivedEventArgs(winsdk.system.Object):
    relative_time: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionInfraredFrameArrivedEventArgs: ...
    def try_open_frame(self) -> typing.Optional[PerceptionInfraredFrame]: ...

class PerceptionInfraredFrameReader(winsdk.system.Object):
    is_paused: winsdk.system.Boolean
    source: typing.Optional[PerceptionInfraredFrameSource]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionInfraredFrameReader: ...
    def close(self) -> None: ...
    def try_read_latest_frame(self) -> typing.Optional[PerceptionInfraredFrame]: ...
    def add_frame_arrived(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionInfraredFrameReader, PerceptionInfraredFrameArrivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_arrived(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PerceptionInfraredFrameSource(winsdk.system.Object):
    active: winsdk.system.Boolean
    available: winsdk.system.Boolean
    available_video_profiles: typing.Optional[winsdk.windows.foundation.collections.IVectorView[PerceptionVideoProfile]]
    camera_intrinsics: typing.Optional[winsdk.windows.media.devices.core.CameraIntrinsics]
    device_kind: str
    display_name: str
    id: str
    is_controlled: winsdk.system.Boolean
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]]
    supported_video_profiles: typing.Optional[winsdk.windows.foundation.collections.IVectorView[PerceptionVideoProfile]]
    video_profile: typing.Optional[PerceptionVideoProfile]
    device_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionInfraredFrameSource: ...
    def acquire_control_session(self) -> typing.Optional[PerceptionControlSession]: ...
    def can_control_independently_from(self, target_id: str) -> winsdk.system.Boolean: ...
    @staticmethod
    def create_watcher() -> typing.Optional[PerceptionInfraredFrameSourceWatcher]: ...
    @staticmethod
    def find_all_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[PerceptionInfraredFrameSource]]: ...
    @staticmethod
    def from_id_async(id: str) -> winsdk.windows.foundation.IAsyncOperation[PerceptionInfraredFrameSource]: ...
    def is_correlated_with(self, target_id: str) -> winsdk.system.Boolean: ...
    def open_reader(self) -> typing.Optional[PerceptionInfraredFrameReader]: ...
    @staticmethod
    def request_access_async() -> winsdk.windows.foundation.IAsyncOperation[PerceptionFrameSourceAccessStatus]: ...
    def try_get_depth_correlated_camera_intrinsics_async(self, target: typing.Optional[PerceptionDepthFrameSource]) -> winsdk.windows.foundation.IAsyncOperation[PerceptionDepthCorrelatedCameraIntrinsics]: ...
    def try_get_depth_correlated_coordinate_mapper_async(self, target_id: str, depth_frame_source_to_map_with: typing.Optional[PerceptionDepthFrameSource]) -> winsdk.windows.foundation.IAsyncOperation[PerceptionDepthCorrelatedCoordinateMapper]: ...
    def try_get_transform_to(self, target_id: str) -> typing.Tuple[winsdk.system.Boolean, winsdk.windows.foundation.numerics.Matrix4x4]: ...
    def try_set_video_profile_async(self, control_session: typing.Optional[PerceptionControlSession], profile: typing.Optional[PerceptionVideoProfile]) -> winsdk.windows.foundation.IAsyncOperation[PerceptionFrameSourcePropertyChangeResult]: ...
    def add_active_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionInfraredFrameSource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_active_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_available_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionInfraredFrameSource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_available_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_camera_intrinsics_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionInfraredFrameSource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_camera_intrinsics_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_properties_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionInfraredFrameSource, PerceptionFrameSourcePropertiesChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_properties_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_video_profile_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionInfraredFrameSource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_video_profile_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PerceptionInfraredFrameSourceAddedEventArgs(winsdk.system.Object):
    frame_source: typing.Optional[PerceptionInfraredFrameSource]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionInfraredFrameSourceAddedEventArgs: ...

class PerceptionInfraredFrameSourceRemovedEventArgs(winsdk.system.Object):
    frame_source: typing.Optional[PerceptionInfraredFrameSource]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionInfraredFrameSourceRemovedEventArgs: ...

class PerceptionInfraredFrameSourceWatcher(winsdk.system.Object):
    status: winsdk.windows.devices.enumeration.DeviceWatcherStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionInfraredFrameSourceWatcher: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    def add_enumeration_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionInfraredFrameSourceWatcher, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_enumeration_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_source_added(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionInfraredFrameSourceWatcher, PerceptionInfraredFrameSourceAddedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_source_added(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_source_removed(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionInfraredFrameSourceWatcher, PerceptionInfraredFrameSourceRemovedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_source_removed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_stopped(self, handler: winsdk.windows.foundation.TypedEventHandler[PerceptionInfraredFrameSourceWatcher, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_stopped(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PerceptionVideoProfile(winsdk.system.Object):
    bitmap_alpha_mode: winsdk.windows.graphics.imaging.BitmapAlphaMode
    bitmap_pixel_format: winsdk.windows.graphics.imaging.BitmapPixelFormat
    frame_duration: datetime.timedelta
    height: winsdk.system.Int32
    width: winsdk.system.Int32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PerceptionVideoProfile: ...
    def is_equal(self, other: typing.Optional[PerceptionVideoProfile]) -> winsdk.system.Boolean: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.security.credentials

class DeviceAccountAuthenticationType(enum.IntEnum):
    BASIC = 0
    O_AUTH = 1
    SINGLE_SIGN_ON = 2

class DeviceAccountIconId(enum.IntEnum):
    EXCHANGE = 0
    MSA = 1
    OUTLOOK = 2
    GENERIC = 3

class DeviceAccountMailAgeFilter(enum.IntEnum):
    ALL = 0
    LAST1_DAY = 1
    LAST3_DAYS = 2
    LAST7_DAYS = 3
    LAST14_DAYS = 4
    LAST30_DAYS = 5
    LAST90_DAYS = 6

class DeviceAccountServerType(enum.IntEnum):
    EXCHANGE = 0
    POP = 1
    IMAP = 2

class DeviceAccountSyncScheduleKind(enum.IntEnum):
    MANUAL = 0
    EVERY15_MINUTES = 1
    EVERY30_MINUTES = 2
    EVERY60_MINUTES = 3
    EVERY2_HOURS = 4
    DAILY = 5
    AS_ITEMS_ARRIVE = 6

Self = typing.TypeVar('Self')

class DeviceAccountConfiguration(winsdk.system.Object):
    email_address: str
    domain: str
    device_account_type_id: str
    outgoing_server_address: str
    contacts_sync_enabled: winsdk.system.Boolean
    calendar_sync_enabled: winsdk.system.Boolean
    account_name: str
    incoming_server_username: str
    incoming_server_requires_ssl: winsdk.system.Boolean
    incoming_server_port: winsdk.system.Int32
    incoming_server_address: str
    email_sync_enabled: winsdk.system.Boolean
    server_type: DeviceAccountServerType
    outgoing_server_username: str
    outgoing_server_requires_ssl: winsdk.system.Boolean
    outgoing_server_port: winsdk.system.Int32
    account_icon_id: DeviceAccountIconId
    cal_dav_server_url: typing.Optional[winsdk.windows.foundation.Uri]
    cal_dav_requires_ssl: winsdk.system.Boolean
    auto_select_authentication_certificate: winsdk.system.Boolean
    authentication_type: DeviceAccountAuthenticationType
    authentication_certificate_id: str
    is_outgoing_server_authentication_enabled: winsdk.system.Boolean
    is_client_authentication_certificate_required: winsdk.system.Boolean
    incoming_server_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    is_outgoing_server_authentication_required: winsdk.system.Boolean
    card_dav_sync_schedule_kind: DeviceAccountSyncScheduleKind
    always_download_full_message: winsdk.system.Boolean
    card_dav_server_url: typing.Optional[winsdk.windows.foundation.Uri]
    card_dav_requires_ssl: winsdk.system.Boolean
    cal_dav_sync_schedule_kind: DeviceAccountSyncScheduleKind
    incoming_server_certificate_hash: str
    was_outgoing_server_certificate_hash_confirmed: winsdk.system.Boolean
    was_modified_by_user: winsdk.system.Boolean
    sync_schedule_kind: DeviceAccountSyncScheduleKind
    sso_account_id: str
    was_incoming_server_certificate_hash_confirmed: winsdk.system.Boolean
    o_auth_refresh_token: str
    is_externally_managed: winsdk.system.Boolean
    mail_age_filter: DeviceAccountMailAgeFilter
    is_sync_schedule_managed_by_system: winsdk.system.Boolean
    outgoing_server_certificate_hash: str
    outgoing_server_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    does_policy_allow_mail_sync: winsdk.system.Boolean
    is_sso_authentication_supported: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceAccountConfiguration: ...
    def __new__(cls: typing.Type[DeviceAccountConfiguration]) -> DeviceAccountConfiguration:...

class UserDataAccountSystemAccessManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataAccountSystemAccessManager: ...
    @staticmethod
    def add_and_show_device_accounts_async(accounts: typing.Iterable[DeviceAccountConfiguration]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[str]]: ...
    @staticmethod
    def create_device_account_async(account: typing.Optional[DeviceAccountConfiguration]) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @staticmethod
    def delete_device_account_async(account_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def get_device_account_configuration_async(account_id: str) -> winsdk.windows.foundation.IAsyncOperation[DeviceAccountConfiguration]: ...
    @staticmethod
    def suppress_local_account_with_account_async(user_data_account_id: str) -> winsdk.windows.foundation.IAsyncAction: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Data.Text")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.ui.text.core
except ImportError:
    pass

class AlternateNormalizationFormat(enum.IntEnum):
    NOT_NORMALIZED = 0
    NUMBER = 1
    CURRENCY = 3
    DATE = 4
    TIME = 5

class TextPredictionOptions(enum.IntFlag):
    NONE = 0
    PREDICTIONS = 0x1
    CORRECTIONS = 0x2

class UnicodeGeneralCategory(enum.IntEnum):
    UPPERCASE_LETTER = 0
    LOWERCASE_LETTER = 1
    TITLECASE_LETTER = 2
    MODIFIER_LETTER = 3
    OTHER_LETTER = 4
    NONSPACING_MARK = 5
    SPACING_COMBINING_MARK = 6
    ENCLOSING_MARK = 7
    DECIMAL_DIGIT_NUMBER = 8
    LETTER_NUMBER = 9
    OTHER_NUMBER = 10
    SPACE_SEPARATOR = 11
    LINE_SEPARATOR = 12
    PARAGRAPH_SEPARATOR = 13
    CONTROL = 14
    FORMAT = 15
    SURROGATE = 16
    PRIVATE_USE = 17
    CONNECTOR_PUNCTUATION = 18
    DASH_PUNCTUATION = 19
    OPEN_PUNCTUATION = 20
    CLOSE_PUNCTUATION = 21
    INITIAL_QUOTE_PUNCTUATION = 22
    FINAL_QUOTE_PUNCTUATION = 23
    OTHER_PUNCTUATION = 24
    MATH_SYMBOL = 25
    CURRENCY_SYMBOL = 26
    MODIFIER_SYMBOL = 27
    OTHER_SYMBOL = 28
    NOT_ASSIGNED = 29

class UnicodeNumericType(enum.IntEnum):
    NONE = 0
    DECIMAL = 1
    DIGIT = 2
    NUMERIC = 3

_ns_module._register_AlternateNormalizationFormat(AlternateNormalizationFormat)
_ns_module._register_TextPredictionOptions(TextPredictionOptions)
_ns_module._register_UnicodeGeneralCategory(UnicodeGeneralCategory)
_ns_module._register_UnicodeNumericType(UnicodeNumericType)

TextSegment = _ns_module.TextSegment
AlternateWordForm = _ns_module.AlternateWordForm
SelectableWordSegment = _ns_module.SelectableWordSegment
SelectableWordsSegmenter = _ns_module.SelectableWordsSegmenter
SemanticTextQuery = _ns_module.SemanticTextQuery
TextConversionGenerator = _ns_module.TextConversionGenerator
TextPhoneme = _ns_module.TextPhoneme
TextPredictionGenerator = _ns_module.TextPredictionGenerator
TextReverseConversionGenerator = _ns_module.TextReverseConversionGenerator
UnicodeCharacters = _ns_module.UnicodeCharacters
WordSegment = _ns_module.WordSegment
WordsSegmenter = _ns_module.WordsSegmenter



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.appointments
import winsdk.windows.applicationmodel.email
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams

class AccessoryNotificationType(enum.IntFlag):
    NONE = 0
    PHONE = 0x1
    EMAIL = 0x2
    REMINDER = 0x4
    ALARM = 0x8
    TOAST = 0x10
    APP_UNINSTALLED = 0x20
    DND = 0x40
    DRIVING_MODE = 0x80
    BATTERY_SAVER = 0x100
    MEDIA = 0x200
    CORTANA_TILE = 0x400
    TOAST_CLEARED = 0x800
    CALENDAR_CHANGED = 0x1000
    VOLUME_CHANGED = 0x2000
    EMAIL_READ_STATUS_CHANGED = 0x4000

class CalendarChangedEvent(enum.IntEnum):
    LOST_EVENTS = 0
    APPOINTMENT_ADDED = 1
    APPOINTMENT_CHANGED = 2
    APPOINTMENT_DELETED = 3
    CALENDAR_ADDED = 4
    CALENDAR_CHANGED = 5
    CALENDAR_DELETED = 6

class PhoneCallAudioEndpoint(enum.IntEnum):
    DEFAULT = 0
    SPEAKER = 1
    HANDSFREE = 2

class PhoneCallDirection(enum.IntEnum):
    INCOMING = 0
    OUTGOING = 1

class PhoneCallState(enum.IntEnum):
    UNKNOWN = 0
    RINGING = 1
    TALKING = 2
    HELD = 3
    ENDED = 4

class PhoneCallTransport(enum.IntEnum):
    CELLULAR = 0
    VOIP = 1

class PhoneLineRegistrationState(enum.IntEnum):
    DISCONNECTED = 0
    HOME = 1
    ROAMING = 2

class PhoneMediaType(enum.IntEnum):
    AUDIO_ONLY = 0
    AUDIO_VIDEO = 1

class PhoneNotificationType(enum.IntEnum):
    NEW_CALL = 0
    CALL_CHANGED = 1
    LINE_CHANGED = 2
    PHONE_CALL_AUDIO_ENDPOINT_CHANGED = 3
    PHONE_MUTE_CHANGED = 4

class PlaybackCapability(enum.IntFlag):
    NONE = 0
    PLAY = 0x1
    PAUSE = 0x2
    STOP = 0x4
    RECORD = 0x8
    FAST_FORWARD = 0x10
    REWIND = 0x20
    NEXT = 0x40
    PREVIOUS = 0x80
    CHANNEL_UP = 0x100
    CHANNEL_DOWN = 0x200

class PlaybackCommand(enum.IntEnum):
    PLAY = 0
    PAUSE = 1
    STOP = 2
    RECORD = 3
    FAST_FORWARD = 4
    REWIND = 5
    NEXT = 6
    PREVIOUS = 7
    CHANNEL_UP = 8
    CHANNEL_DOWN = 9

class PlaybackStatus(enum.IntEnum):
    NONE = 0
    TRACK_CHANGED = 1
    STOPPED = 2
    PLAYING = 3
    PAUSED = 4

class ReminderState(enum.IntEnum):
    ACTIVE = 0
    SNOOZED = 1
    DISMISSED = 2

class VibrateState(enum.IntEnum):
    RINGER_OFF_VIBRATE_OFF = 0
    RINGER_OFF_VIBRATE_ON = 1
    RINGER_ON_VIBRATE_OFF = 2
    RINGER_ON_VIBRATE_ON = 3

Self = typing.TypeVar('Self')

class AccessoryManager(winsdk.system.Object):
    phone_mute: typing.ClassVar[winsdk.system.Boolean]
    phone_call_audio_endpoint: typing.ClassVar[PhoneCallAudioEndpoint]
    battery_saver_state: typing.ClassVar[winsdk.system.Boolean]
    do_not_disturb_enabled: typing.ClassVar[winsdk.system.Boolean]
    driving_mode_enabled: typing.ClassVar[winsdk.system.Boolean]
    media_playback_capabilities: typing.ClassVar[PlaybackCapability]
    media_playback_status: typing.ClassVar[PlaybackStatus]
    phone_line_details: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[PhoneLineDetails]]]
    is_phone_pin_locked: typing.ClassVar[winsdk.system.Boolean]
    speed_dial_list: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[SpeedDialEntry]]]
    volume_info: typing.ClassVar[typing.Optional[VolumeInfo]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AccessoryManager: ...
    @typing.overload
    @staticmethod
    def accept_phone_call(phone_call_id: winsdk.system.UInt32) -> None: ...
    @typing.overload
    @staticmethod
    def accept_phone_call(phone_call_id: winsdk.system.UInt32, end_point: PhoneCallAudioEndpoint) -> None: ...
    @typing.overload
    @staticmethod
    def accept_phone_call_with_video(phone_call_id: winsdk.system.UInt32) -> None: ...
    @typing.overload
    @staticmethod
    def accept_phone_call_with_video(phone_call_id: winsdk.system.UInt32, end_point: PhoneCallAudioEndpoint) -> None: ...
    @staticmethod
    def clear_toast(instance_id: str) -> None: ...
    @staticmethod
    def decrease_volume(step: winsdk.system.Int32) -> None: ...
    @staticmethod
    def disable_all_accessory_notification_types() -> None: ...
    @staticmethod
    def disable_email_notification_email_account(email_account: str) -> None: ...
    @staticmethod
    def disable_notifications_for_application(app_id: str) -> None: ...
    @staticmethod
    def dismiss_alarm(alarm_id: winsdk.system.Guid) -> None: ...
    @staticmethod
    def dismiss_alarm_by_instance_id(instance_id: str) -> None: ...
    @staticmethod
    def dismiss_reminder(reminder_id: winsdk.system.Guid) -> None: ...
    @staticmethod
    def dismiss_reminder_by_instance_id(instance_id: str) -> None: ...
    @staticmethod
    def enable_accessory_notification_types(accessory_notification_types: winsdk.system.Int32) -> None: ...
    @staticmethod
    def enable_email_notification_email_account(email_account: str) -> None: ...
    @staticmethod
    def enable_email_notification_folder_filter(email_account: str, folders: winsdk.windows.foundation.collections.IVectorView[str]) -> None: ...
    @staticmethod
    def enable_notifications_for_application(app_id: str) -> None: ...
    @staticmethod
    def end_phone_call(phone_call_id: winsdk.system.UInt32) -> None: ...
    @staticmethod
    def get_all_email_accounts() -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[EmailAccountInfo]]: ...
    @staticmethod
    def get_app_icon(app_id: str) -> typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]: ...
    @staticmethod
    def get_apps() -> typing.Optional[winsdk.windows.foundation.collections.IMapView[str, AppNotificationInfo]]: ...
    @staticmethod
    def get_enabled_accessory_notification_types() -> winsdk.system.Int32: ...
    @staticmethod
    def get_folders(email_account: str) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[EmailFolderInfo]]: ...
    @staticmethod
    def get_media_metadata() -> typing.Optional[MediaMetadata]: ...
    @staticmethod
    def get_next_trigger_details() -> typing.Optional[IAccessoryNotificationTriggerDetails]: ...
    @staticmethod
    def get_phone_line_details(phone_line: winsdk.system.Guid) -> typing.Optional[PhoneLineDetails]: ...
    @staticmethod
    def get_user_consent() -> winsdk.system.Boolean: ...
    @staticmethod
    def hold_phone_call(phone_call_id: winsdk.system.UInt32, hold_call: winsdk.system.Boolean) -> None: ...
    @staticmethod
    def increase_volume(step: winsdk.system.Int32) -> None: ...
    @staticmethod
    def is_notification_enabled_for_application(app_id: str) -> winsdk.system.Boolean: ...
    @typing.overload
    @staticmethod
    def make_phone_call(phone_line: winsdk.system.Guid, phone_number: str) -> None: ...
    @typing.overload
    @staticmethod
    def make_phone_call(phone_line: winsdk.system.Guid, phone_number: str, end_point: PhoneCallAudioEndpoint) -> None: ...
    @typing.overload
    @staticmethod
    def make_phone_call_with_video(phone_line: winsdk.system.Guid, phone_number: str) -> None: ...
    @typing.overload
    @staticmethod
    def make_phone_call_with_video(phone_line: winsdk.system.Guid, phone_number: str, end_point: PhoneCallAudioEndpoint) -> None: ...
    @staticmethod
    def perform_media_playback_command(command: PlaybackCommand) -> None: ...
    @staticmethod
    def process_trigger_details(p_details: typing.Optional[IAccessoryNotificationTriggerDetails]) -> None: ...
    @staticmethod
    def register_accessory_app() -> str: ...
    @typing.overload
    @staticmethod
    def reject_phone_call(phone_call_id: winsdk.system.UInt32) -> None: ...
    @typing.overload
    @staticmethod
    def reject_phone_call(phone_call_id: winsdk.system.UInt32, text_response_i_d: winsdk.system.UInt32) -> None: ...
    @staticmethod
    def ring_device() -> None: ...
    @staticmethod
    def set_mute(mute: winsdk.system.Boolean) -> None: ...
    @staticmethod
    def set_ringer_vibrate(ringer: winsdk.system.Boolean, vibrate: winsdk.system.Boolean) -> None: ...
    @typing.overload
    @staticmethod
    def snooze_alarm(alarm_id: winsdk.system.Guid) -> None: ...
    @typing.overload
    @staticmethod
    def snooze_alarm(alarm_id: winsdk.system.Guid, time_span: datetime.timedelta) -> None: ...
    @staticmethod
    def snooze_alarm_by_instance_id(instance_id: str) -> None: ...
    @typing.overload
    @staticmethod
    def snooze_reminder(reminder_id: winsdk.system.Guid) -> None: ...
    @typing.overload
    @staticmethod
    def snooze_reminder(reminder_id: winsdk.system.Guid, time_span: datetime.timedelta) -> None: ...
    @staticmethod
    def snooze_reminder_by_instance_id(instance_id: str) -> None: ...
    @staticmethod
    def swap_phone_calls(phone_call_id_to_hold: winsdk.system.UInt32, phone_call_id_on_hold: winsdk.system.UInt32) -> None: ...
    @staticmethod
    def update_email_read_status(message_entry_id: typing.Optional[BinaryId], is_read: winsdk.system.Boolean) -> None: ...

class AlarmNotificationTriggerDetails(winsdk.system.Object):
    started_processing: winsdk.system.Boolean
    accessory_notification_type: AccessoryNotificationType
    app_display_name: str
    app_id: str
    time_created: datetime.datetime
    alarm_id: winsdk.system.Guid
    reminder_state: ReminderState
    timestamp: datetime.datetime
    title: str
    instance_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AlarmNotificationTriggerDetails: ...

class AppNotificationInfo(winsdk.system.Object):
    id: str
    name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppNotificationInfo: ...

class BinaryId(winsdk.system.Object):
    id: winsdk.system.UInt8
    length: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BinaryId: ...

class CalendarChangedNotificationTriggerDetails(winsdk.system.Object):
    started_processing: winsdk.system.Boolean
    accessory_notification_type: AccessoryNotificationType
    app_display_name: str
    app_id: str
    time_created: datetime.datetime
    event_type: CalendarChangedEvent
    item_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CalendarChangedNotificationTriggerDetails: ...

class CortanaTileNotificationTriggerDetails(winsdk.system.Object):
    started_processing: winsdk.system.Boolean
    accessory_notification_type: AccessoryNotificationType
    app_display_name: str
    app_id: str
    time_created: datetime.datetime
    content: str
    emphasized_text: str
    large_content1: str
    large_content2: str
    non_wrapped_small_content1: str
    non_wrapped_small_content2: str
    non_wrapped_small_content3: str
    non_wrapped_small_content4: str
    source: str
    tile_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CortanaTileNotificationTriggerDetails: ...

class EmailAccountInfo(winsdk.system.Object):
    display_name: str
    is_notification_enabled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailAccountInfo: ...

class EmailFolderInfo(winsdk.system.Object):
    display_name: str
    is_notification_enabled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailFolderInfo: ...

class EmailNotificationTriggerDetails(winsdk.system.Object):
    started_processing: winsdk.system.Boolean
    accessory_notification_type: AccessoryNotificationType
    app_display_name: str
    app_id: str
    time_created: datetime.datetime
    account_name: str
    email_message: typing.Optional[winsdk.windows.applicationmodel.email.EmailMessage]
    parent_folder_name: str
    sender_address: str
    sender_name: str
    timestamp: datetime.datetime
    message_entry_id: typing.Optional[BinaryId]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailNotificationTriggerDetails: ...

class EmailReadNotificationTriggerDetails(winsdk.system.Object):
    started_processing: winsdk.system.Boolean
    accessory_notification_type: AccessoryNotificationType
    app_display_name: str
    app_id: str
    time_created: datetime.datetime
    account_name: str
    is_read: winsdk.system.Boolean
    message_entry_id: typing.Optional[BinaryId]
    parent_folder_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailReadNotificationTriggerDetails: ...

class MediaControlsTriggerDetails(winsdk.system.Object):
    started_processing: winsdk.system.Boolean
    accessory_notification_type: AccessoryNotificationType
    app_display_name: str
    app_id: str
    time_created: datetime.datetime
    media_metadata: typing.Optional[MediaMetadata]
    playback_status: PlaybackStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaControlsTriggerDetails: ...

class MediaMetadata(winsdk.system.Object):
    album: str
    artist: str
    duration: datetime.timedelta
    subtitle: str
    thumbnail: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    title: str
    track: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaMetadata: ...

class PhoneCallDetails(winsdk.system.Object):
    call_direction: PhoneCallDirection
    call_id: winsdk.system.UInt32
    call_media_type: PhoneMediaType
    call_transport: PhoneCallTransport
    conference_call_id: winsdk.system.UInt32
    contact_name: str
    end_time: datetime.datetime
    phone_line: winsdk.system.Guid
    phone_number: str
    preset_text_responses: typing.Optional[winsdk.windows.foundation.collections.IVectorView[TextResponse]]
    start_time: datetime.datetime
    state: PhoneCallState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PhoneCallDetails: ...

class PhoneLineDetails(winsdk.system.Object):
    default_outgoing_line: winsdk.system.Boolean
    display_name: str
    line_id: winsdk.system.Guid
    line_number: str
    registration_state: PhoneLineRegistrationState
    voicemail_count: winsdk.system.UInt32
    missed_call_count: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PhoneLineDetails: ...

class PhoneNotificationTriggerDetails(winsdk.system.Object):
    started_processing: winsdk.system.Boolean
    accessory_notification_type: AccessoryNotificationType
    app_display_name: str
    app_id: str
    time_created: datetime.datetime
    call_details: typing.Optional[PhoneCallDetails]
    phone_line_changed_id: winsdk.system.Guid
    phone_notification_type: PhoneNotificationType
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PhoneNotificationTriggerDetails: ...

class ReminderNotificationTriggerDetails(winsdk.system.Object):
    started_processing: winsdk.system.Boolean
    accessory_notification_type: AccessoryNotificationType
    app_display_name: str
    app_id: str
    time_created: datetime.datetime
    appointment: typing.Optional[winsdk.windows.applicationmodel.appointments.Appointment]
    description: str
    details: str
    reminder_id: winsdk.system.Guid
    reminder_state: ReminderState
    timestamp: datetime.datetime
    title: str
    instance_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ReminderNotificationTriggerDetails: ...

class SpeedDialEntry(winsdk.system.Object):
    contact_name: str
    number_type: str
    phone_number: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpeedDialEntry: ...

class TextResponse(winsdk.system.Object):
    content: str
    id: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TextResponse: ...

class ToastNotificationTriggerDetails(winsdk.system.Object):
    started_processing: winsdk.system.Boolean
    accessory_notification_type: AccessoryNotificationType
    app_display_name: str
    app_id: str
    time_created: datetime.datetime
    suppress_popup: winsdk.system.Boolean
    text1: str
    text2: str
    text3: str
    text4: str
    instance_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ToastNotificationTriggerDetails: ...

class VolumeInfo(winsdk.system.Object):
    call_volume: winsdk.system.UInt32
    is_muted: winsdk.system.Boolean
    is_vibrate_enabled: VibrateState
    media_volume: winsdk.system.UInt32
    system_volume: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VolumeInfo: ...

class IAccessoryNotificationTriggerDetails(winsdk.system.Object):
    accessory_notification_type: AccessoryNotificationType
    app_display_name: str
    app_id: str
    started_processing: winsdk.system.Boolean
    time_created: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IAccessoryNotificationTriggerDetails: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.storage.streams

Self = typing.TypeVar('Self')

class DataProtectionProvider(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataProtectionProvider: ...
    @typing.overload
    def __new__(cls: typing.Type[DataProtectionProvider], protection_descriptor: str) -> DataProtectionProvider:...
    @typing.overload
    def __new__(cls: typing.Type[DataProtectionProvider]) -> DataProtectionProvider:...
    def protect_async(self, data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IBuffer]: ...
    def protect_stream_async(self, src: typing.Optional[winsdk.windows.storage.streams.IInputStream], dest: typing.Optional[winsdk.windows.storage.streams.IOutputStream]) -> winsdk.windows.foundation.IAsyncAction: ...
    def unprotect_async(self, data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IBuffer]: ...
    def unprotect_stream_async(self, src: typing.Optional[winsdk.windows.storage.streams.IInputStream], dest: typing.Optional[winsdk.windows.storage.streams.IOutputStream]) -> winsdk.windows.foundation.IAsyncAction: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.data.xml.dom

Self = typing.TypeVar('Self')

class XsltProcessor(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XsltProcessor: ...
    def __new__(cls: typing.Type[XsltProcessor], document: typing.Optional[winsdk.windows.data.xml.dom.XmlDocument]) -> XsltProcessor:...
    def transform_to_document(self, input_node: typing.Optional[winsdk.windows.data.xml.dom.IXmlNode]) -> typing.Optional[winsdk.windows.data.xml.dom.XmlDocument]: ...
    def transform_to_string(self, input_node: typing.Optional[winsdk.windows.data.xml.dom.IXmlNode]) -> str: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.core
import winsdk.windows.system
import winsdk.windows.ui.core
import winsdk.windows.ui.input

Self = typing.TypeVar('Self')

class RadialControllerIndependentInputSource(winsdk.system.Object):
    controller: typing.Optional[winsdk.windows.ui.input.RadialController]
    dispatcher: typing.Optional[winsdk.windows.ui.core.CoreDispatcher]
    dispatcher_queue: typing.Optional[winsdk.windows.system.DispatcherQueue]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RadialControllerIndependentInputSource: ...
    @staticmethod
    def create_for_view(view: typing.Optional[winsdk.windows.applicationmodel.core.CoreApplicationView]) -> typing.Optional[RadialControllerIndependentInputSource]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams

Self = typing.TypeVar('Self')

class LockApplicationHost(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LockApplicationHost: ...
    @staticmethod
    def get_for_current_view() -> typing.Optional[LockApplicationHost]: ...
    def request_unlock(self) -> None: ...
    def add_unlocking(self, handler: winsdk.windows.foundation.TypedEventHandler[LockApplicationHost, LockScreenUnlockingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_unlocking(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class LockScreenBadge(winsdk.system.Object):
    automation_name: str
    glyph: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]
    logo: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]
    number: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LockScreenBadge: ...
    def launch_app(self) -> None: ...

class LockScreenInfo(winsdk.system.Object):
    alarm_icon: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]
    badges: typing.Optional[winsdk.windows.foundation.collections.IVectorView[LockScreenBadge]]
    detail_text: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    lock_screen_image: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LockScreenInfo: ...
    def add_alarm_icon_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[LockScreenInfo, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_alarm_icon_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_badges_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[LockScreenInfo, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_badges_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_detail_text_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[LockScreenInfo, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_detail_text_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_lock_screen_image_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[LockScreenInfo, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_lock_screen_image_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class LockScreenUnlockingDeferral(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LockScreenUnlockingDeferral: ...
    def complete(self) -> None: ...

class LockScreenUnlockingEventArgs(winsdk.system.Object):
    deadline: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LockScreenUnlockingEventArgs: ...
    def get_deferral(self) -> typing.Optional[LockScreenUnlockingDeferral]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.System.Threading")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

class WorkItemOptions(enum.IntFlag):
    NONE = 0
    TIME_SLICED = 0x1

class WorkItemPriority(enum.IntEnum):
    LOW = -1
    NORMAL = 0
    HIGH = 1

_ns_module._register_WorkItemOptions(WorkItemOptions)
_ns_module._register_WorkItemPriority(WorkItemPriority)

ThreadPool = _ns_module.ThreadPool
ThreadPoolTimer = _ns_module.ThreadPoolTimer



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Core.Preview")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.ui.windowmanagement
except ImportError:
    pass


CoreAppWindowPreview = _ns_module.CoreAppWindowPreview
SystemNavigationCloseRequestedPreviewEventArgs = _ns_module.SystemNavigationCloseRequestedPreviewEventArgs
SystemNavigationManagerPreview = _ns_module.SystemNavigationManagerPreview



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Appointments")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

try:
    import winsdk.windows.ui.popups
except ImportError:
    pass

class AppointmentBusyStatus(enum.IntEnum):
    BUSY = 0
    TENTATIVE = 1
    FREE = 2
    OUT_OF_OFFICE = 3
    WORKING_ELSEWHERE = 4

class AppointmentCalendarOtherAppReadAccess(enum.IntEnum):
    SYSTEM_ONLY = 0
    LIMITED = 1
    FULL = 2
    NONE = 3

class AppointmentCalendarOtherAppWriteAccess(enum.IntEnum):
    NONE = 0
    SYSTEM_ONLY = 1
    LIMITED = 2

class AppointmentCalendarSyncStatus(enum.IntEnum):
    IDLE = 0
    SYNCING = 1
    UP_TO_DATE = 2
    AUTHENTICATION_ERROR = 3
    POLICY_ERROR = 4
    UNKNOWN_ERROR = 5
    MANUAL_ACCOUNT_REMOVAL_REQUIRED = 6

class AppointmentConflictType(enum.IntEnum):
    NONE = 0
    ADJACENT = 1
    OVERLAP = 2

class AppointmentDaysOfWeek(enum.IntFlag):
    NONE = 0
    SUNDAY = 0x1
    MONDAY = 0x2
    TUESDAY = 0x4
    WEDNESDAY = 0x8
    THURSDAY = 0x10
    FRIDAY = 0x20
    SATURDAY = 0x40

class AppointmentDetailsKind(enum.IntEnum):
    PLAIN_TEXT = 0
    HTML = 1

class AppointmentParticipantResponse(enum.IntEnum):
    NONE = 0
    TENTATIVE = 1
    ACCEPTED = 2
    DECLINED = 3
    UNKNOWN = 4

class AppointmentParticipantRole(enum.IntEnum):
    REQUIRED_ATTENDEE = 0
    OPTIONAL_ATTENDEE = 1
    RESOURCE = 2

class AppointmentRecurrenceUnit(enum.IntEnum):
    DAILY = 0
    WEEKLY = 1
    MONTHLY = 2
    MONTHLY_ON_DAY = 3
    YEARLY = 4
    YEARLY_ON_DAY = 5

class AppointmentSensitivity(enum.IntEnum):
    PUBLIC = 0
    PRIVATE = 1

class AppointmentStoreAccessType(enum.IntEnum):
    APP_CALENDARS_READ_WRITE = 0
    ALL_CALENDARS_READ_ONLY = 1
    ALL_CALENDARS_READ_WRITE = 2

class AppointmentStoreChangeType(enum.IntEnum):
    APPOINTMENT_CREATED = 0
    APPOINTMENT_MODIFIED = 1
    APPOINTMENT_DELETED = 2
    CHANGE_TRACKING_LOST = 3
    CALENDAR_CREATED = 4
    CALENDAR_MODIFIED = 5
    CALENDAR_DELETED = 6

class AppointmentSummaryCardView(enum.IntEnum):
    SYSTEM = 0
    APP = 1

class AppointmentWeekOfMonth(enum.IntEnum):
    FIRST = 0
    SECOND = 1
    THIRD = 2
    FOURTH = 3
    LAST = 4

class FindAppointmentCalendarsOptions(enum.IntFlag):
    NONE = 0
    INCLUDE_HIDDEN = 0x1

class RecurrenceType(enum.IntEnum):
    MASTER = 0
    INSTANCE = 1
    EXCEPTION_INSTANCE = 2

_ns_module._register_AppointmentBusyStatus(AppointmentBusyStatus)
_ns_module._register_AppointmentCalendarOtherAppReadAccess(AppointmentCalendarOtherAppReadAccess)
_ns_module._register_AppointmentCalendarOtherAppWriteAccess(AppointmentCalendarOtherAppWriteAccess)
_ns_module._register_AppointmentCalendarSyncStatus(AppointmentCalendarSyncStatus)
_ns_module._register_AppointmentConflictType(AppointmentConflictType)
_ns_module._register_AppointmentDaysOfWeek(AppointmentDaysOfWeek)
_ns_module._register_AppointmentDetailsKind(AppointmentDetailsKind)
_ns_module._register_AppointmentParticipantResponse(AppointmentParticipantResponse)
_ns_module._register_AppointmentParticipantRole(AppointmentParticipantRole)
_ns_module._register_AppointmentRecurrenceUnit(AppointmentRecurrenceUnit)
_ns_module._register_AppointmentSensitivity(AppointmentSensitivity)
_ns_module._register_AppointmentStoreAccessType(AppointmentStoreAccessType)
_ns_module._register_AppointmentStoreChangeType(AppointmentStoreChangeType)
_ns_module._register_AppointmentSummaryCardView(AppointmentSummaryCardView)
_ns_module._register_AppointmentWeekOfMonth(AppointmentWeekOfMonth)
_ns_module._register_FindAppointmentCalendarsOptions(FindAppointmentCalendarsOptions)
_ns_module._register_RecurrenceType(RecurrenceType)

Appointment = _ns_module.Appointment
AppointmentCalendar = _ns_module.AppointmentCalendar
AppointmentCalendarSyncManager = _ns_module.AppointmentCalendarSyncManager
AppointmentConflictResult = _ns_module.AppointmentConflictResult
AppointmentException = _ns_module.AppointmentException
AppointmentInvitee = _ns_module.AppointmentInvitee
AppointmentManager = _ns_module.AppointmentManager
AppointmentManagerForUser = _ns_module.AppointmentManagerForUser
AppointmentOrganizer = _ns_module.AppointmentOrganizer
AppointmentProperties = _ns_module.AppointmentProperties
AppointmentRecurrence = _ns_module.AppointmentRecurrence
AppointmentStore = _ns_module.AppointmentStore
AppointmentStoreChange = _ns_module.AppointmentStoreChange
AppointmentStoreChangeReader = _ns_module.AppointmentStoreChangeReader
AppointmentStoreChangeTracker = _ns_module.AppointmentStoreChangeTracker
AppointmentStoreChangedDeferral = _ns_module.AppointmentStoreChangedDeferral
AppointmentStoreChangedEventArgs = _ns_module.AppointmentStoreChangedEventArgs
AppointmentStoreNotificationTriggerDetails = _ns_module.AppointmentStoreNotificationTriggerDetails
FindAppointmentsOptions = _ns_module.FindAppointmentsOptions
IAppointmentParticipant = _ns_module.IAppointmentParticipant



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.ui

class WebUICommandBarClosedDisplayMode(enum.IntEnum):
    DEFAULT = 0
    MINIMAL = 1
    COMPACT = 2

Self = typing.TypeVar('Self')

class WebUICommandBar(winsdk.system.Object):
    visible: winsdk.system.Boolean
    opacity: winsdk.system.Double
    is_open: winsdk.system.Boolean
    foreground_color: winsdk.windows.ui.Color
    closed_display_mode: WebUICommandBarClosedDisplayMode
    background_color: winsdk.windows.ui.Color
    primary_commands: typing.Optional[winsdk.windows.foundation.collections.IObservableVector[IWebUICommandBarElement]]
    secondary_commands: typing.Optional[winsdk.windows.foundation.collections.IObservableVector[IWebUICommandBarElement]]
    size: winsdk.windows.foundation.Size
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUICommandBar: ...
    @staticmethod
    def get_for_current_view() -> typing.Optional[WebUICommandBar]: ...
    def add_menu_closed(self, handler: typing.Optional[MenuClosedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_menu_closed(self, value: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_menu_opened(self, handler: typing.Optional[MenuOpenedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_menu_opened(self, value: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_size_changed(self, handler: typing.Optional[SizeChangedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_size_changed(self, value: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class WebUICommandBarBitmapIcon(winsdk.system.Object):
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUICommandBarBitmapIcon: ...
    @typing.overload
    def __new__(cls: typing.Type[WebUICommandBarBitmapIcon], uri: typing.Optional[winsdk.windows.foundation.Uri]) -> WebUICommandBarBitmapIcon:...
    @typing.overload
    def __new__(cls: typing.Type[WebUICommandBarBitmapIcon]) -> WebUICommandBarBitmapIcon:...

class WebUICommandBarConfirmationButton(winsdk.system.Object):
    text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUICommandBarConfirmationButton: ...
    def __new__(cls: typing.Type[WebUICommandBarConfirmationButton]) -> WebUICommandBarConfirmationButton:...
    def add_item_invoked(self, handler: winsdk.windows.foundation.TypedEventHandler[WebUICommandBarConfirmationButton, WebUICommandBarItemInvokedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_item_invoked(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class WebUICommandBarIconButton(winsdk.system.Object):
    label: str
    is_toggle_button: winsdk.system.Boolean
    is_checked: winsdk.system.Boolean
    icon: typing.Optional[IWebUICommandBarIcon]
    enabled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUICommandBarIconButton: ...
    def __new__(cls: typing.Type[WebUICommandBarIconButton]) -> WebUICommandBarIconButton:...
    def add_item_invoked(self, handler: winsdk.windows.foundation.TypedEventHandler[WebUICommandBarIconButton, WebUICommandBarItemInvokedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_item_invoked(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class WebUICommandBarItemInvokedEventArgs(winsdk.system.Object):
    is_primary_command: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUICommandBarItemInvokedEventArgs: ...

class WebUICommandBarSizeChangedEventArgs(winsdk.system.Object):
    size: winsdk.windows.foundation.Size
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUICommandBarSizeChangedEventArgs: ...

class WebUICommandBarSymbolIcon(winsdk.system.Object):
    symbol: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUICommandBarSymbolIcon: ...
    @typing.overload
    def __new__(cls: typing.Type[WebUICommandBarSymbolIcon], symbol: str) -> WebUICommandBarSymbolIcon:...
    @typing.overload
    def __new__(cls: typing.Type[WebUICommandBarSymbolIcon]) -> WebUICommandBarSymbolIcon:...

class IWebUICommandBarElement(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebUICommandBarElement: ...

class IWebUICommandBarIcon(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebUICommandBarIcon: ...

MenuClosedEventHandler = typing.Callable[[], None]

MenuOpenedEventHandler = typing.Callable[[], None]

SizeChangedEventHandler = typing.Callable[[typing.Optional[WebUICommandBarSizeChangedEventArgs]], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

class TokenBindingKeyType(enum.IntEnum):
    RSA2048 = 0
    ECDSA_P256 = 1
    ANY_EXISTING = 2

class WebAuthenticationOptions(enum.IntFlag):
    NONE = 0
    SILENT_MODE = 0x1
    USE_TITLE = 0x2
    USE_HTTP_POST = 0x4
    USE_CORPORATE_NETWORK = 0x8

class WebAuthenticationStatus(enum.IntEnum):
    SUCCESS = 0
    USER_CANCEL = 1
    ERROR_HTTP = 2

Self = typing.TypeVar('Self')

class WebAuthenticationBroker(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAuthenticationBroker: ...
    @typing.overload
    @staticmethod
    def authenticate_and_continue(request_uri: typing.Optional[winsdk.windows.foundation.Uri]) -> None: ...
    @typing.overload
    @staticmethod
    def authenticate_and_continue(request_uri: typing.Optional[winsdk.windows.foundation.Uri], callback_uri: typing.Optional[winsdk.windows.foundation.Uri]) -> None: ...
    @typing.overload
    @staticmethod
    def authenticate_and_continue(request_uri: typing.Optional[winsdk.windows.foundation.Uri], callback_uri: typing.Optional[winsdk.windows.foundation.Uri], continuation_data: typing.Optional[winsdk.windows.foundation.collections.ValueSet], options: WebAuthenticationOptions) -> None: ...
    @typing.overload
    @staticmethod
    def authenticate_async(options: WebAuthenticationOptions, request_uri: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncOperation[WebAuthenticationResult]: ...
    @typing.overload
    @staticmethod
    def authenticate_async(options: WebAuthenticationOptions, request_uri: typing.Optional[winsdk.windows.foundation.Uri], callback_uri: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncOperation[WebAuthenticationResult]: ...
    @typing.overload
    @staticmethod
    def authenticate_silently_async(request_uri: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncOperation[WebAuthenticationResult]: ...
    @typing.overload
    @staticmethod
    def authenticate_silently_async(request_uri: typing.Optional[winsdk.windows.foundation.Uri], options: WebAuthenticationOptions) -> winsdk.windows.foundation.IAsyncOperation[WebAuthenticationResult]: ...
    @staticmethod
    def get_current_application_callback_uri() -> typing.Optional[winsdk.windows.foundation.Uri]: ...

class WebAuthenticationResult(winsdk.system.Object):
    response_data: str
    response_error_detail: winsdk.system.UInt32
    response_status: WebAuthenticationStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAuthenticationResult: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Graphics.Printing.PrintSupport")

try:
    import winsdk.windows.applicationmodel
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.activation
except ImportError:
    pass

try:
    import winsdk.windows.data.xml.dom
except ImportError:
    pass

try:
    import winsdk.windows.devices.printers
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.graphics.printing.printticket
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui.shell
except ImportError:
    pass

class SettingsLaunchKind(enum.IntEnum):
    JOB_PRINT_TICKET = 0
    USER_DEFAULT_PRINT_TICKET = 1

class WorkflowPrintTicketValidationStatus(enum.IntEnum):
    RESOLVED = 0
    CONFLICTING = 1
    INVALID = 2

_ns_module._register_SettingsLaunchKind(SettingsLaunchKind)
_ns_module._register_WorkflowPrintTicketValidationStatus(WorkflowPrintTicketValidationStatus)

PrintSupportExtensionSession = _ns_module.PrintSupportExtensionSession
PrintSupportExtensionTriggerDetails = _ns_module.PrintSupportExtensionTriggerDetails
PrintSupportPrintDeviceCapabilitiesChangedEventArgs = _ns_module.PrintSupportPrintDeviceCapabilitiesChangedEventArgs
PrintSupportPrintDeviceCapabilitiesUpdatePolicy = _ns_module.PrintSupportPrintDeviceCapabilitiesUpdatePolicy
PrintSupportPrintTicketElement = _ns_module.PrintSupportPrintTicketElement
PrintSupportPrintTicketValidationRequestedEventArgs = _ns_module.PrintSupportPrintTicketValidationRequestedEventArgs
PrintSupportPrinterSelectedEventArgs = _ns_module.PrintSupportPrinterSelectedEventArgs
PrintSupportSessionInfo = _ns_module.PrintSupportSessionInfo
PrintSupportSettingsActivatedEventArgs = _ns_module.PrintSupportSettingsActivatedEventArgs
PrintSupportSettingsUISession = _ns_module.PrintSupportSettingsUISession



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.pointofservice
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.graphics.imaging
import winsdk.windows.storage.streams

class BarcodeScannerTriggerState(enum.IntEnum):
    RELEASED = 0
    PRESSED = 1

Self = typing.TypeVar('Self')

class BarcodeScannerDisableScannerRequest(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerDisableScannerRequest: ...
    def report_completed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32, failed_reason_description: str) -> winsdk.windows.foundation.IAsyncAction: ...

class BarcodeScannerDisableScannerRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[BarcodeScannerDisableScannerRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerDisableScannerRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class BarcodeScannerEnableScannerRequest(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerEnableScannerRequest: ...
    def report_completed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32, failed_reason_description: str) -> winsdk.windows.foundation.IAsyncAction: ...

class BarcodeScannerEnableScannerRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[BarcodeScannerEnableScannerRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerEnableScannerRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class BarcodeScannerFrameReader(winsdk.system.Object):
    connection: typing.Optional[BarcodeScannerProviderConnection]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerFrameReader: ...
    def close(self) -> None: ...
    def start_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def stop_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def try_acquire_latest_frame_async(self) -> winsdk.windows.foundation.IAsyncOperation[BarcodeScannerVideoFrame]: ...
    def add_frame_arrived(self, handler: winsdk.windows.foundation.TypedEventHandler[BarcodeScannerFrameReader, BarcodeScannerFrameReaderFrameArrivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_arrived(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class BarcodeScannerFrameReaderFrameArrivedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerFrameReaderFrameArrivedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class BarcodeScannerGetSymbologyAttributesRequest(winsdk.system.Object):
    symbology: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerGetSymbologyAttributesRequest: ...
    def report_completed_async(self, attributes: typing.Optional[winsdk.windows.devices.pointofservice.BarcodeSymbologyAttributes]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32, failed_reason_description: str) -> winsdk.windows.foundation.IAsyncAction: ...

class BarcodeScannerGetSymbologyAttributesRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[BarcodeScannerGetSymbologyAttributesRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerGetSymbologyAttributesRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class BarcodeScannerHideVideoPreviewRequest(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerHideVideoPreviewRequest: ...
    def report_completed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32, failed_reason_description: str) -> winsdk.windows.foundation.IAsyncAction: ...

class BarcodeScannerHideVideoPreviewRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[BarcodeScannerHideVideoPreviewRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerHideVideoPreviewRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class BarcodeScannerProviderConnection(winsdk.system.Object):
    version: str
    name: str
    company_name: str
    id: str
    supported_symbologies: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.system.UInt32]]
    video_device_id: str
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerProviderConnection: ...
    def close(self) -> None: ...
    @typing.overload
    def create_frame_reader_async(self) -> winsdk.windows.foundation.IAsyncOperation[BarcodeScannerFrameReader]: ...
    @typing.overload
    def create_frame_reader_async(self, preferred_format: winsdk.windows.graphics.imaging.BitmapPixelFormat) -> winsdk.windows.foundation.IAsyncOperation[BarcodeScannerFrameReader]: ...
    @typing.overload
    def create_frame_reader_async(self, preferred_format: winsdk.windows.graphics.imaging.BitmapPixelFormat, preferred_size: winsdk.windows.graphics.imaging.BitmapSize) -> winsdk.windows.foundation.IAsyncOperation[BarcodeScannerFrameReader]: ...
    @typing.overload
    def report_error_async(self, error_data: typing.Optional[winsdk.windows.devices.pointofservice.UnifiedPosErrorData]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_error_async(self, error_data: typing.Optional[winsdk.windows.devices.pointofservice.UnifiedPosErrorData], is_retriable: winsdk.system.Boolean, scan_report: typing.Optional[winsdk.windows.devices.pointofservice.BarcodeScannerReport]) -> winsdk.windows.foundation.IAsyncAction: ...
    def report_scanned_data_async(self, report: typing.Optional[winsdk.windows.devices.pointofservice.BarcodeScannerReport]) -> winsdk.windows.foundation.IAsyncAction: ...
    def report_trigger_state_async(self, state: BarcodeScannerTriggerState) -> winsdk.windows.foundation.IAsyncAction: ...
    def start(self) -> None: ...
    def add_disable_scanner_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[BarcodeScannerProviderConnection, BarcodeScannerDisableScannerRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_disable_scanner_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_enable_scanner_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[BarcodeScannerProviderConnection, BarcodeScannerEnableScannerRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_enable_scanner_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_get_barcode_symbology_attributes_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[BarcodeScannerProviderConnection, BarcodeScannerGetSymbologyAttributesRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_get_barcode_symbology_attributes_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_hide_video_preview_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[BarcodeScannerProviderConnection, BarcodeScannerHideVideoPreviewRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_hide_video_preview_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_set_active_symbologies_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[BarcodeScannerProviderConnection, BarcodeScannerSetActiveSymbologiesRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_set_active_symbologies_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_set_barcode_symbology_attributes_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[BarcodeScannerProviderConnection, BarcodeScannerSetSymbologyAttributesRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_set_barcode_symbology_attributes_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_start_software_trigger_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[BarcodeScannerProviderConnection, BarcodeScannerStartSoftwareTriggerRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_start_software_trigger_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_stop_software_trigger_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[BarcodeScannerProviderConnection, BarcodeScannerStopSoftwareTriggerRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_stop_software_trigger_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class BarcodeScannerProviderTriggerDetails(winsdk.system.Object):
    connection: typing.Optional[BarcodeScannerProviderConnection]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerProviderTriggerDetails: ...

class BarcodeScannerSetActiveSymbologiesRequest(winsdk.system.Object):
    symbologies: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.UInt32]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerSetActiveSymbologiesRequest: ...
    def report_completed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32, failed_reason_description: str) -> winsdk.windows.foundation.IAsyncAction: ...

class BarcodeScannerSetActiveSymbologiesRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[BarcodeScannerSetActiveSymbologiesRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerSetActiveSymbologiesRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class BarcodeScannerSetSymbologyAttributesRequest(winsdk.system.Object):
    attributes: typing.Optional[winsdk.windows.devices.pointofservice.BarcodeSymbologyAttributes]
    symbology: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerSetSymbologyAttributesRequest: ...
    def report_completed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32, failed_reason_description: str) -> winsdk.windows.foundation.IAsyncAction: ...

class BarcodeScannerSetSymbologyAttributesRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[BarcodeScannerSetSymbologyAttributesRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerSetSymbologyAttributesRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class BarcodeScannerStartSoftwareTriggerRequest(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerStartSoftwareTriggerRequest: ...
    def report_completed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32, failed_reason_description: str) -> winsdk.windows.foundation.IAsyncAction: ...

class BarcodeScannerStartSoftwareTriggerRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[BarcodeScannerStartSoftwareTriggerRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerStartSoftwareTriggerRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class BarcodeScannerStopSoftwareTriggerRequest(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerStopSoftwareTriggerRequest: ...
    def report_completed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def report_failed_async(self, reason: winsdk.system.Int32, failed_reason_description: str) -> winsdk.windows.foundation.IAsyncAction: ...

class BarcodeScannerStopSoftwareTriggerRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[BarcodeScannerStopSoftwareTriggerRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerStopSoftwareTriggerRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class BarcodeScannerVideoFrame(winsdk.system.Object):
    format: winsdk.windows.graphics.imaging.BitmapPixelFormat
    height: winsdk.system.UInt32
    pixel_data: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    width: winsdk.system.UInt32
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeScannerVideoFrame: ...
    def close(self) -> None: ...

class BarcodeSymbologyAttributesBuilder(winsdk.system.Object):
    is_decode_length_supported: winsdk.system.Boolean
    is_check_digit_validation_supported: winsdk.system.Boolean
    is_check_digit_transmission_supported: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BarcodeSymbologyAttributesBuilder: ...
    def __new__(cls: typing.Type[BarcodeSymbologyAttributesBuilder]) -> BarcodeSymbologyAttributesBuilder:...
    def create_attributes(self) -> typing.Optional[winsdk.windows.devices.pointofservice.BarcodeSymbologyAttributes]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation

class ExtendedExecutionReason(enum.IntEnum):
    UNSPECIFIED = 0
    LOCATION_TRACKING = 1
    SAVING_DATA = 2

class ExtendedExecutionResult(enum.IntEnum):
    ALLOWED = 0
    DENIED = 1

class ExtendedExecutionRevokedReason(enum.IntEnum):
    RESUMED = 0
    SYSTEM_POLICY = 1

Self = typing.TypeVar('Self')

class ExtendedExecutionRevokedEventArgs(winsdk.system.Object):
    reason: ExtendedExecutionRevokedReason
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ExtendedExecutionRevokedEventArgs: ...

class ExtendedExecutionSession(winsdk.system.Object):
    reason: ExtendedExecutionReason
    percent_progress: winsdk.system.UInt32
    description: str
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ExtendedExecutionSession: ...
    def __new__(cls: typing.Type[ExtendedExecutionSession]) -> ExtendedExecutionSession:...
    def close(self) -> None: ...
    def request_extension_async(self) -> winsdk.windows.foundation.IAsyncOperation[ExtendedExecutionResult]: ...
    def add_revoked(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.system.Object, ExtendedExecutionRevokedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_revoked(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Adc.Provider")

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class ProviderAdcChannelMode(enum.IntEnum):
    SINGLE_ENDED = 0
    DIFFERENTIAL = 1

_ns_module._register_ProviderAdcChannelMode(ProviderAdcChannelMode)

IAdcControllerProvider = _ns_module.IAdcControllerProvider
IAdcProvider = _ns_module.IAdcProvider



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.networking
import winsdk.windows.networking.connectivity
import winsdk.windows.networking.sockets

class DnssdRegistrationStatus(enum.IntEnum):
    SUCCESS = 0
    INVALID_SERVICE_NAME = 1
    SERVER_ERROR = 2
    SECURITY_ERROR = 3

class DnssdServiceWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    ENUMERATION_COMPLETED = 2
    STOPPING = 3
    STOPPED = 4
    ABORTED = 5

Self = typing.TypeVar('Self')

class DnssdRegistrationResult(winsdk.system.Object):
    has_instance_name_changed: winsdk.system.Boolean
    ip_address: typing.Optional[winsdk.windows.networking.HostName]
    status: DnssdRegistrationStatus
    def __str__(self) -> str: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DnssdRegistrationResult: ...
    def __new__(cls: typing.Type[DnssdRegistrationResult]) -> DnssdRegistrationResult:...
    def to_string(self) -> str: ...

class DnssdServiceInstance(winsdk.system.Object):
    weight: winsdk.system.UInt16
    priority: winsdk.system.UInt16
    port: winsdk.system.UInt16
    host_name: typing.Optional[winsdk.windows.networking.HostName]
    dnssd_service_instance_name: str
    text_attributes: typing.Optional[winsdk.windows.foundation.collections.IMap[str, str]]
    def __str__(self) -> str: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DnssdServiceInstance: ...
    def __new__(cls: typing.Type[DnssdServiceInstance], dnssd_service_instance_name: str, host_name: typing.Optional[winsdk.windows.networking.HostName], port: winsdk.system.UInt16) -> DnssdServiceInstance:...
    @typing.overload
    def register_datagram_socket_async(self, socket: typing.Optional[winsdk.windows.networking.sockets.DatagramSocket]) -> winsdk.windows.foundation.IAsyncOperation[DnssdRegistrationResult]: ...
    @typing.overload
    def register_datagram_socket_async(self, socket: typing.Optional[winsdk.windows.networking.sockets.DatagramSocket], adapter: typing.Optional[winsdk.windows.networking.connectivity.NetworkAdapter]) -> winsdk.windows.foundation.IAsyncOperation[DnssdRegistrationResult]: ...
    @typing.overload
    def register_stream_socket_listener_async(self, socket: typing.Optional[winsdk.windows.networking.sockets.StreamSocketListener]) -> winsdk.windows.foundation.IAsyncOperation[DnssdRegistrationResult]: ...
    @typing.overload
    def register_stream_socket_listener_async(self, socket: typing.Optional[winsdk.windows.networking.sockets.StreamSocketListener], adapter: typing.Optional[winsdk.windows.networking.connectivity.NetworkAdapter]) -> winsdk.windows.foundation.IAsyncOperation[DnssdRegistrationResult]: ...
    def to_string(self) -> str: ...

class DnssdServiceInstanceCollection(winsdk.system.Object, typing.Sequence[DnssdServiceInstance]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: int) -> DnssdServiceInstance: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winsdk.system.Array[DnssdServiceInstance]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DnssdServiceInstanceCollection: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[DnssdServiceInstance]]: ...
    def get_at(self, index: winsdk.system.UInt32) -> typing.Optional[DnssdServiceInstance]: ...
    def get_many(self, start_index: winsdk.system.UInt32, items: winsdk.system.Array[DnssdServiceInstance]) -> winsdk.system.UInt32: ...
    def index_of(self, value: typing.Optional[DnssdServiceInstance]) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.UInt32]: ...

class DnssdServiceWatcher(winsdk.system.Object):
    status: DnssdServiceWatcherStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DnssdServiceWatcher: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    def add_added(self, handler: winsdk.windows.foundation.TypedEventHandler[DnssdServiceWatcher, DnssdServiceInstance]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_added(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_enumeration_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[DnssdServiceWatcher, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_enumeration_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_stopped(self, handler: winsdk.windows.foundation.TypedEventHandler[DnssdServiceWatcher, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_stopped(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.VoiceCommands")

try:
    import winsdk.windows.applicationmodel.appservice
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.globalization
except ImportError:
    pass

try:
    import winsdk.windows.media.speechrecognition
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

class VoiceCommandCompletionReason(enum.IntEnum):
    UNKNOWN = 0
    COMMUNICATION_FAILED = 1
    RESOURCE_LIMITS_EXCEEDED = 2
    CANCELED = 3
    TIMEOUT_EXCEEDED = 4
    APP_LAUNCHED = 5
    COMPLETED = 6

class VoiceCommandContentTileType(enum.IntEnum):
    TITLE_ONLY = 0
    TITLE_WITH_TEXT = 1
    TITLE_WITH68X68_ICON = 2
    TITLE_WITH68X68_ICON_AND_TEXT = 3
    TITLE_WITH68X92_ICON = 4
    TITLE_WITH68X92_ICON_AND_TEXT = 5
    TITLE_WITH280X140_ICON = 6
    TITLE_WITH280X140_ICON_AND_TEXT = 7

_ns_module._register_VoiceCommandCompletionReason(VoiceCommandCompletionReason)
_ns_module._register_VoiceCommandContentTileType(VoiceCommandContentTileType)

VoiceCommand = _ns_module.VoiceCommand
VoiceCommandCompletedEventArgs = _ns_module.VoiceCommandCompletedEventArgs
VoiceCommandConfirmationResult = _ns_module.VoiceCommandConfirmationResult
VoiceCommandContentTile = _ns_module.VoiceCommandContentTile
VoiceCommandDefinition = _ns_module.VoiceCommandDefinition
VoiceCommandDefinitionManager = _ns_module.VoiceCommandDefinitionManager
VoiceCommandDisambiguationResult = _ns_module.VoiceCommandDisambiguationResult
VoiceCommandResponse = _ns_module.VoiceCommandResponse
VoiceCommandServiceConnection = _ns_module.VoiceCommandServiceConnection
VoiceCommandUserMessage = _ns_module.VoiceCommandUserMessage



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.media.core
import winsdk.windows.media.mediaproperties
import winsdk.windows.storage
import winsdk.windows.storage.streams

class MediaVideoProcessingAlgorithm(enum.IntEnum):
    DEFAULT = 0
    MRF_CRF444 = 1

class TranscodeFailureReason(enum.IntEnum):
    NONE = 0
    UNKNOWN = 1
    INVALID_PROFILE = 2
    CODEC_NOT_FOUND = 3

Self = typing.TypeVar('Self')

class MediaTranscoder(winsdk.system.Object):
    trim_stop_time: datetime.timedelta
    trim_start_time: datetime.timedelta
    hardware_acceleration_enabled: winsdk.system.Boolean
    always_reencode: winsdk.system.Boolean
    video_processing_algorithm: MediaVideoProcessingAlgorithm
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaTranscoder: ...
    def __new__(cls: typing.Type[MediaTranscoder]) -> MediaTranscoder:...
    @typing.overload
    def add_audio_effect(self, activatable_class_id: str) -> None: ...
    @typing.overload
    def add_audio_effect(self, activatable_class_id: str, effect_required: winsdk.system.Boolean, configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...
    @typing.overload
    def add_video_effect(self, activatable_class_id: str) -> None: ...
    @typing.overload
    def add_video_effect(self, activatable_class_id: str, effect_required: winsdk.system.Boolean, configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...
    def clear_effects(self) -> None: ...
    def prepare_file_transcode_async(self, source: typing.Optional[winsdk.windows.storage.IStorageFile], destination: typing.Optional[winsdk.windows.storage.IStorageFile], profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile]) -> winsdk.windows.foundation.IAsyncOperation[PrepareTranscodeResult]: ...
    def prepare_media_stream_source_transcode_async(self, source: typing.Optional[winsdk.windows.media.core.IMediaSource], destination: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream], profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile]) -> winsdk.windows.foundation.IAsyncOperation[PrepareTranscodeResult]: ...
    def prepare_stream_transcode_async(self, source: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream], destination: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream], profile: typing.Optional[winsdk.windows.media.mediaproperties.MediaEncodingProfile]) -> winsdk.windows.foundation.IAsyncOperation[PrepareTranscodeResult]: ...

class PrepareTranscodeResult(winsdk.system.Object):
    can_transcode: winsdk.system.Boolean
    failure_reason: TranscodeFailureReason
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrepareTranscodeResult: ...
    def transcode_async(self) -> winsdk.windows.foundation.IAsyncActionWithProgress[winsdk.system.Double]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Perception.People")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.numerics
except ImportError:
    pass

try:
    import winsdk.windows.perception
except ImportError:
    pass

try:
    import winsdk.windows.perception.spatial
except ImportError:
    pass

try:
    import winsdk.windows.ui.input
except ImportError:
    pass

try:
    import winsdk.windows.ui.input.spatial
except ImportError:
    pass

class HandJointKind(enum.IntEnum):
    PALM = 0
    WRIST = 1
    THUMB_METACARPAL = 2
    THUMB_PROXIMAL = 3
    THUMB_DISTAL = 4
    THUMB_TIP = 5
    INDEX_METACARPAL = 6
    INDEX_PROXIMAL = 7
    INDEX_INTERMEDIATE = 8
    INDEX_DISTAL = 9
    INDEX_TIP = 10
    MIDDLE_METACARPAL = 11
    MIDDLE_PROXIMAL = 12
    MIDDLE_INTERMEDIATE = 13
    MIDDLE_DISTAL = 14
    MIDDLE_TIP = 15
    RING_METACARPAL = 16
    RING_PROXIMAL = 17
    RING_INTERMEDIATE = 18
    RING_DISTAL = 19
    RING_TIP = 20
    LITTLE_METACARPAL = 21
    LITTLE_PROXIMAL = 22
    LITTLE_INTERMEDIATE = 23
    LITTLE_DISTAL = 24
    LITTLE_TIP = 25

class JointPoseAccuracy(enum.IntEnum):
    HIGH = 0
    APPROXIMATE = 1

_ns_module._register_HandJointKind(HandJointKind)
_ns_module._register_JointPoseAccuracy(JointPoseAccuracy)

HandMeshVertex = _ns_module.HandMeshVertex
JointPose = _ns_module.JointPose
EyesPose = _ns_module.EyesPose
HandMeshObserver = _ns_module.HandMeshObserver
HandMeshVertexState = _ns_module.HandMeshVertexState
HandPose = _ns_module.HandPose
HeadPose = _ns_module.HeadPose



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

Self = typing.TypeVar('Self')

class DeviceLockdownProfile(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceLockdownProfile: ...
    @staticmethod
    def apply_lockdown_profile_async(profile_i_d: winsdk.system.Guid) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def get_current_lockdown_profile() -> winsdk.system.Guid: ...
    @staticmethod
    def get_lockdown_profile_information(profile_i_d: winsdk.system.Guid) -> typing.Optional[DeviceLockdownProfileInformation]: ...
    @staticmethod
    def get_supported_lockdown_profiles() -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Guid]]: ...

class DeviceLockdownProfileInformation(winsdk.system.Object):
    name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceLockdownProfileInformation: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Networking.Proximity")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.networking
except ImportError:
    pass

try:
    import winsdk.windows.networking.sockets
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class PeerDiscoveryTypes(enum.IntFlag):
    NONE = 0
    BROWSE = 0x1
    TRIGGERED = 0x2

class PeerRole(enum.IntEnum):
    PEER = 0
    HOST = 1
    CLIENT = 2

class PeerWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    ENUMERATION_COMPLETED = 2
    STOPPING = 3
    STOPPED = 4
    ABORTED = 5

class TriggeredConnectState(enum.IntEnum):
    PEER_FOUND = 0
    LISTENING = 1
    CONNECTING = 2
    COMPLETED = 3
    CANCELED = 4
    FAILED = 5

_ns_module._register_PeerDiscoveryTypes(PeerDiscoveryTypes)
_ns_module._register_PeerRole(PeerRole)
_ns_module._register_PeerWatcherStatus(PeerWatcherStatus)
_ns_module._register_TriggeredConnectState(TriggeredConnectState)

ConnectionRequestedEventArgs = _ns_module.ConnectionRequestedEventArgs
PeerFinder = _ns_module.PeerFinder
PeerInformation = _ns_module.PeerInformation
PeerWatcher = _ns_module.PeerWatcher
ProximityDevice = _ns_module.ProximityDevice
ProximityMessage = _ns_module.ProximityMessage
TriggeredConnectionStateChangedEventArgs = _ns_module.TriggeredConnectionStateChangedEventArgs



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.appservice
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.globalization
import winsdk.windows.media.speechrecognition
import winsdk.windows.storage

class VoiceCommandCompletionReason(enum.IntEnum):
    UNKNOWN = 0
    COMMUNICATION_FAILED = 1
    RESOURCE_LIMITS_EXCEEDED = 2
    CANCELED = 3
    TIMEOUT_EXCEEDED = 4
    APP_LAUNCHED = 5
    COMPLETED = 6

class VoiceCommandContentTileType(enum.IntEnum):
    TITLE_ONLY = 0
    TITLE_WITH_TEXT = 1
    TITLE_WITH68X68_ICON = 2
    TITLE_WITH68X68_ICON_AND_TEXT = 3
    TITLE_WITH68X92_ICON = 4
    TITLE_WITH68X92_ICON_AND_TEXT = 5
    TITLE_WITH280X140_ICON = 6
    TITLE_WITH280X140_ICON_AND_TEXT = 7

Self = typing.TypeVar('Self')

class VoiceCommand(winsdk.system.Object):
    command_name: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.windows.foundation.collections.IVectorView[str]]]
    speech_recognition_result: typing.Optional[winsdk.windows.media.speechrecognition.SpeechRecognitionResult]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VoiceCommand: ...

class VoiceCommandCompletedEventArgs(winsdk.system.Object):
    reason: VoiceCommandCompletionReason
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VoiceCommandCompletedEventArgs: ...

class VoiceCommandConfirmationResult(winsdk.system.Object):
    confirmed: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VoiceCommandConfirmationResult: ...

class VoiceCommandContentTile(winsdk.system.Object):
    title: str
    text_line3: str
    text_line2: str
    text_line1: str
    image: typing.Optional[winsdk.windows.storage.IStorageFile]
    content_tile_type: VoiceCommandContentTileType
    app_launch_argument: str
    app_context: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VoiceCommandContentTile: ...
    def __new__(cls: typing.Type[VoiceCommandContentTile]) -> VoiceCommandContentTile:...

class VoiceCommandDefinition(winsdk.system.Object):
    language: str
    name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VoiceCommandDefinition: ...
    def set_phrase_list_async(self, phrase_list_name: str, phrase_list: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncAction: ...

class VoiceCommandDefinitionManager(winsdk.system.Object):
    installed_command_definitions: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IMapView[str, VoiceCommandDefinition]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VoiceCommandDefinitionManager: ...
    @staticmethod
    def install_command_definitions_from_storage_file_async(file: typing.Optional[winsdk.windows.storage.StorageFile]) -> winsdk.windows.foundation.IAsyncAction: ...

class VoiceCommandDisambiguationResult(winsdk.system.Object):
    selected_item: typing.Optional[VoiceCommandContentTile]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VoiceCommandDisambiguationResult: ...

class VoiceCommandResponse(winsdk.system.Object):
    repeat_message: typing.Optional[VoiceCommandUserMessage]
    message: typing.Optional[VoiceCommandUserMessage]
    app_launch_argument: str
    voice_command_content_tiles: typing.Optional[winsdk.windows.foundation.collections.IVector[VoiceCommandContentTile]]
    max_supported_voice_command_content_tiles: typing.ClassVar[winsdk.system.UInt32]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VoiceCommandResponse: ...
    @typing.overload
    @staticmethod
    def create_response(user_message: typing.Optional[VoiceCommandUserMessage]) -> typing.Optional[VoiceCommandResponse]: ...
    @typing.overload
    @staticmethod
    def create_response(message: typing.Optional[VoiceCommandUserMessage], content_tiles: typing.Iterable[VoiceCommandContentTile]) -> typing.Optional[VoiceCommandResponse]: ...
    @typing.overload
    @staticmethod
    def create_response_for_prompt(message: typing.Optional[VoiceCommandUserMessage], repeat_message: typing.Optional[VoiceCommandUserMessage]) -> typing.Optional[VoiceCommandResponse]: ...
    @typing.overload
    @staticmethod
    def create_response_for_prompt(message: typing.Optional[VoiceCommandUserMessage], repeat_message: typing.Optional[VoiceCommandUserMessage], content_tiles: typing.Iterable[VoiceCommandContentTile]) -> typing.Optional[VoiceCommandResponse]: ...

class VoiceCommandServiceConnection(winsdk.system.Object):
    language: typing.Optional[winsdk.windows.globalization.Language]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VoiceCommandServiceConnection: ...
    @staticmethod
    def from_app_service_trigger_details(trigger_details: typing.Optional[winsdk.windows.applicationmodel.appservice.AppServiceTriggerDetails]) -> typing.Optional[VoiceCommandServiceConnection]: ...
    def get_voice_command_async(self) -> winsdk.windows.foundation.IAsyncOperation[VoiceCommand]: ...
    def report_failure_async(self, response: typing.Optional[VoiceCommandResponse]) -> winsdk.windows.foundation.IAsyncAction: ...
    def report_progress_async(self, response: typing.Optional[VoiceCommandResponse]) -> winsdk.windows.foundation.IAsyncAction: ...
    def report_success_async(self, response: typing.Optional[VoiceCommandResponse]) -> winsdk.windows.foundation.IAsyncAction: ...
    def request_app_launch_async(self, response: typing.Optional[VoiceCommandResponse]) -> winsdk.windows.foundation.IAsyncAction: ...
    def request_confirmation_async(self, response: typing.Optional[VoiceCommandResponse]) -> winsdk.windows.foundation.IAsyncOperation[VoiceCommandConfirmationResult]: ...
    def request_disambiguation_async(self, response: typing.Optional[VoiceCommandResponse]) -> winsdk.windows.foundation.IAsyncOperation[VoiceCommandDisambiguationResult]: ...
    def add_voice_command_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[VoiceCommandServiceConnection, VoiceCommandCompletedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_voice_command_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class VoiceCommandUserMessage(winsdk.system.Object):
    spoken_message: str
    display_message: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VoiceCommandUserMessage: ...
    def __new__(cls: typing.Type[VoiceCommandUserMessage]) -> VoiceCommandUserMessage:...

